--AH:ScriptId=77dbcc11-5dc9-4972-b80a-da7743766853

BEGIN TRY
	BEGIN TRANSACTION

	-- DELETE Orphaned Vulnerabilities
	DELETE [Vulnerabilities]
		WHERE [Vulnerability_Id] IN (
			SELECT V.[Vulnerability_Id]
				FROM [VulnerabilitySources] VS
					INNER JOIN [FeedVulnerabilitySources] FVS ON VS.VulnerabilitySource_Id = FVS.VulnerabilitySource_Id
					INNER JOIN [Vulnerabilities] V on VS.VulnerabilitySource_Id = V.VulnerabilitySource_Id
				WHERE VS.[Configuration_Xml].value('local-name(/*[1])','VARCHAR(255)') = 'Inedo.ProGet.Extensions.VulnerabilitySources.BuiltInVulnerabilitySource' AND FVS.Feed_Id IS NULL
		)

	-- Update Manual Vulnerabilities to be tied to the oldest Feed Id instead

	UPDATE VU
		SET 
			VU.[Feed_Id] = VL.[Feed_Id], 
			VU.[VulnerabilitySource_Id] = NULL
		FROM [Vulnerabilities] VU
		INNER JOIN (
			SELECT VS.[VulnerabilitySource_Id], [Feed_Id] = MIN(FVS.[Feed_Id])
				FROM [VulnerabilitySources] VS
				INNER JOIN [FeedVulnerabilitySources] FVS ON VS.VulnerabilitySource_Id = FVS.VulnerabilitySource_Id
				WHERE VS.[Configuration_Xml].value('local-name(/*[1])','VARCHAR(255)') = 'Inedo.ProGet.Extensions.VulnerabilitySources.BuiltInVulnerabilitySource' AND FVS.Feed_Id IS NOT NULL
				GROUP BY VS.[VulnerabilitySource_Id]
		) VL ON VU.[VulnerabilitySource_Id] = VL.[VulnerabilitySource_Id]

	-- Remove Feed Vulnerability Sources

	DELETE [FeedVulnerabilitySources]
		WHERE [VulnerabilitySource_Id] IN (
			SELECT VS.[VulnerabilitySource_Id]
				FROM [VulnerabilitySources] VS
				WHERE VS.[Configuration_Xml].value('local-name(/*[1])','VARCHAR(255)') = 'Inedo.ProGet.Extensions.VulnerabilitySources.BuiltInVulnerabilitySource'

			)

	-- Remove Manual Vulnerability sources

	DELETE [VulnerabilitySources]
		WHERE [Configuration_Xml].value('local-name(/*[1])','VARCHAR(255)') = 'Inedo.ProGet.Extensions.VulnerabilitySources.BuiltInVulnerabilitySource'

	COMMIT

END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0
        ROLLBACK TRAN --RollBack in case of Error

	DECLARE @ErrorMessage NVARCHAR(4000) = ERROR_MESSAGE()
    DECLARE @ErrorSeverity INT = ERROR_SEVERITY()
    DECLARE @ErrorState INT = ERROR_STATE()
    RAISERROR(@ErrorMessage, @ErrorSeverity, @ErrorState)
END CATCH